==> igniteui-react-18.2.0-beta.1.tgz: package/esm5/lib/igr-range-slider.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrRangeSliderValueEventArgs } from "./igr-range-slider-value-event-args";
import { IgrSliderBase } from "./igr-slider-base";
import { RangeSlider } from "./RangeSlider";
import { IgcRangeSliderComponent, defineComponents } from "igniteui-webcomponents";
/**
 * A range slider component used to select two numeric values within a range.
*/
var IgrRangeSlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRangeSlider, _super);
    function IgrRangeSlider(props) {
        var _this = _super.call(this, props) || this;
        _this._input = null;
        _this._input_wrapped = null;
        _this._change = null;
        _this._change_wrapped = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcRangeSliderComponent);
        return _this;
    }
    IgrRangeSlider.prototype.createImplementation = function () {
        return new RangeSlider();
    };
    Object.defineProperty(IgrRangeSlider.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrRangeSlider.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrRangeSlider.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-range-slider", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrRangeSlider.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrRangeSlider.prototype, "lower", {
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "upper", {
        get: function () {
            return this.i.ab;
        },
        set: function (v) {
            this.i.ab = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "ariaLabelLower", {
        /**
         * The aria label of the lower thumb.
        */
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "ariaLabelUpper", {
        /**
         * The aria label of the upper thumb.
        */
        get: function () {
            return this.i.ad;
        },
        set: function (v) {
            this.i.ad = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "input", {
        /**
         * Emitted when a value is changed via thumb drag or keyboard interaction.
        */
        get: function () {
            return this._input;
        },
        set: function (ev) {
            var _this = this;
            if (this._input_wrapped !== null) {
                this.i.input = delegateRemove(this.i.input, this._input_wrapped);
                this._input_wrapped = null;
                this._input = null;
            }
            this._input = ev;
            this._input_wrapped = function (o, e) {
                var outerArgs = new IgrRangeSliderValueEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeInput) {
                    _this.beforeInput(_this, outerArgs);
                }
                if (_this._input) {
                    _this._input(_this, outerArgs);
                }
            };
            this.i.input = delegateCombine(this.i.input, this._input_wrapped);
            if (this.i.inputChanged) {
                this.i.inputChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "change", {
        /**
         * Emitted when a value change is committed on a thumb drag end or keyboard interaction.
        */
        get: function () {
            return this._change;
        },
        set: function (ev) {
            var _this = this;
            if (this._change_wrapped !== null) {
                this.i.change = delegateRemove(this.i.change, this._change_wrapped);
                this._change_wrapped = null;
                this._change = null;
            }
            this._change = ev;
            this._change_wrapped = function (o, e) {
                var outerArgs = new IgrRangeSliderValueEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeChange) {
                    _this.beforeChange(_this, outerArgs);
                }
                if (_this._change) {
                    _this._change(_this, outerArgs);
                }
            };
            this.i.change = delegateCombine(this.i.change, this._change_wrapped);
            if (this.i.changeChanged) {
                this.i.changeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrRangeSlider;
}(IgrSliderBase));
export { IgrRangeSlider };

==> igniteui-react-18.5.2-beta.1.tgz: package/esm5/lib/igr-range-slider.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrRangeSliderValueEventArgs } from "./igr-range-slider-value-event-args";
import { IgrSliderBase } from "./igr-slider-base";
import { RangeSlider } from "./RangeSlider";
import { IgcRangeSliderComponent, defineComponents } from "igniteui-webcomponents";
/**
 * A range slider component used to select two numeric values within a range.
*/
var IgrRangeSlider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRangeSlider, _super);
    function IgrRangeSlider(props) {
        var _this = _super.call(this, props) || this;
        _this._input = null;
        _this._input_wrapped = null;
        _this._change = null;
        _this._change_wrapped = null;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcRangeSliderComponent);
        return _this;
    }
    IgrRangeSlider.prototype.createImplementation = function () {
        return new RangeSlider();
    };
    Object.defineProperty(IgrRangeSlider.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrRangeSlider.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrRangeSlider.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-range-slider", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrRangeSlider.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrRangeSlider.prototype, "lower", {
        /**
         * The current value of the lower thumb.
        */
        get: function () {
            return this.i.z;
        },
        set: function (v) {
            this.i.z = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "upper", {
        /**
         * The current value of the upper thumb.
        */
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "thumbLabelLower", {
        /**
         * The aria label for the lower thumb.
        */
        get: function () {
            return this.i.ad;
        },
        set: function (v) {
            this.i.ad = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "thumbLabelUpper", {
        /**
         * The aria label for the upper thumb.
        */
        get: function () {
            return this.i.ae;
        },
        set: function (v) {
            this.i.ae = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "ariaLabelLower", {
        /**
         * The aria label of the lower thumb.
         * @deprecated since v4.8.0. Use the `thumbLabelLower` property instead.
        */
        get: function () {
            return this.i.ab;
        },
        set: function (v) {
            this.i.ab = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "ariaLabelUpper", {
        /**
         * The aria label of the upper thumb.
         * @deprecated since v4.8.0. Use the `thumbLabelUpper` property instead.
        */
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "input", {
        /**
         * Emitted when a value is changed via thumb drag or keyboard interaction.
        */
        get: function () {
            return this._input;
        },
        set: function (ev) {
            var _this = this;
            if (this._input_wrapped !== null) {
                this.i.input = delegateRemove(this.i.input, this._input_wrapped);
                this._input_wrapped = null;
                this._input = null;
            }
            this._input = ev;
            this._input_wrapped = function (o, e) {
                var outerArgs = new IgrRangeSliderValueEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeInput) {
                    _this.beforeInput(_this, outerArgs);
                }
                if (_this._input) {
                    _this._input(_this, outerArgs);
                }
            };
            this.i.input = delegateCombine(this.i.input, this._input_wrapped);
            if (this.i.inputChanged) {
                this.i.inputChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRangeSlider.prototype, "change", {
        /**
         * Emitted when a value change is committed on a thumb drag end or keyboard interaction.
        */
        get: function () {
            return this._change;
        },
        set: function (ev) {
            var _this = this;
            if (this._change_wrapped !== null) {
                this.i.change = delegateRemove(this.i.change, this._change_wrapped);
                this._change_wrapped = null;
                this._change = null;
            }
            this._change = ev;
            this._change_wrapped = function (o, e) {
                var outerArgs = new IgrRangeSliderValueEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeChange) {
                    _this.beforeChange(_this, outerArgs);
                }
                if (_this._change) {
                    _this._change(_this, outerArgs);
                }
            };
            this.i.change = delegateCombine(this.i.change, this._change_wrapped);
            if (this.i.changeChanged) {
                this.i.changeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrRangeSlider;
}(IgrSliderBase));
export { IgrRangeSlider };
